@@ -117,13 +117,12 @@ NULL
   }))
   urls <- unique(all_urls)
   filenames <- file.path(rundir, basename(urls))
+  if (attr(x, "testing")) {
+    return(basename(filenames))
+  }
   # start download in a temporal directory within tmpdir
   # TODO: Parallel downloads
   aria_bin <- attributes(x)$aria_bin
-  if (!is.null(attr(x, "testing"))) {
-    return(filenames)
-  }
-
   .download_or_skip(urls, filenames, verbose, aria_bin = aria_bin, check_existence = FALSE)
 
   # unzip the downloaded file
