@@ -5,6 +5,10 @@ test_that("calc_indicator works", {
     )
   )
 
+  temp_loc <- file.path(tempdir(), "mapme.biodiversity")
+  dir.create(temp_loc, showWarnings = FALSE)
+  resource_dir <- system.file("res", package = "mapme.biodiversity")
+  file.copy(resource_dir, temp_loc, recursive = TRUE)
   outdir <- file.path(tempdir(), "mapme.biodiversity", "res")
   tmpdir <- tempdir()
 
@@ -13,16 +17,20 @@ test_that("calc_indicator works", {
     years = 2000:2005,
     cores = 1,
     outdir = outdir,
-    tmpdir = tmpdir
+    tmpdir = tmpdir,
+    verbose = FALSE
   )
 
   portfolio <- get_resources(portfolio,
-    resources = c("treecover2000", "lossyear")
+    resources = c("treecover2000", "lossyear"),
+    vers_treecover = "GFC-2020-v1.8",
+    vers_lossyear = "GFC-2020-v1.8"
   )
 
   expect_message(
     calc_indicators(portfolio,
-      indicators = "treecover"
+      indicators = "treecover",
+      min_cover = 10
     ),
     "was not specified. Setting to default value"
   )
@@ -32,6 +40,7 @@ test_that("calc_indicator works", {
     min_size = 5,
     min_cover = 30
   )$treecover[[1]]
+
   expect_snapshot(stat)
 
   cores <- ifelse(Sys.info()["sysname"] == "Windows", 1, 2)
@@ -40,10 +49,9 @@ test_that("calc_indicator works", {
     years = 2000:2005,
     cores = cores,
     outdir = outdir,
-    tmpdir = tmpdir
-  )
-  portfolio <- get_resources(portfolio,
-    resources = c("treecover2000", "lossyear")
+    tmpdir = tmpdir,
+    add_resources = TRUE,
+    verbose = FALSE
   )
 
   stat <- calc_indicators(portfolio,
@@ -51,7 +59,6 @@ test_that("calc_indicator works", {
     min_size = 5,
     min_cover = 30
   )$treecover[[1]]
-  expect_snapshot(
-    stat
-  )
+
+  expect_snapshot(stat)
 })
