@@ -1,7 +1,7 @@
 test_that(".get_lossyear works", {
   aoi <- read_sf(
     system.file("extdata", "sierra_de_neiba_478140.gpkg",
-      package = "mapme.biodiversity"
+                package = "mapme.biodiversity"
     )
   )
   aoi <- suppressWarnings(st_cast(aoi, to = "POLYGON")[1, ])
@@ -14,24 +14,18 @@ test_that(".get_lossyear works", {
   tmpdir <- tempdir()
 
   portfolio <- init_portfolio(aoi,
-    years = 2000:2020,
-    outdir = outdir,
-    tmpdir = tmpdir,
-    cores = 1,
-    add_resources = FALSE,
-    verbose = TRUE
+                              years = 2000:2020,
+                              outdir = outdir,
+                              tmpdir = tmpdir,
+                              cores = 1,
+                              add_resources = FALSE,
+                              verbose = FALSE
   )
 
   # Add testing attribute in order to skip downloads
   attributes(portfolio)$testing <- TRUE
-
-  expect_warning(
-    get_resources(portfolio, resources = "lossyear", vers_lossyear = "not-available"),
-    "Download for resource lossyear failed. Returning unmodified portfolio object."
-  )
-
   expect_equal(
-    basename(get_resources(portfolio, resources = "lossyear")),
+    .get_lossyear(portfolio, vers_lossyear = "GFC-2020-v1.8"),
     "Hansen_GFC-2020-v1.8_lossyear_20N_080W.tif"
   )
 })
