@@ -4,6 +4,7 @@ test_that("get_resources works", {
       package = "mapme.biodiversity"
     )
   )
+  aoi <- suppressWarnings(st_cast(aoi, to = "POLYGON")[1, ])
 
   temp_loc <- file.path(tempdir(), "mapme.biodiversity")
   dir.create(temp_loc, showWarnings = FALSE)
@@ -12,25 +13,19 @@ test_that("get_resources works", {
   outdir <- file.path(tempdir(), "mapme.biodiversity", "res")
   tmpdir <- tempdir()
 
-  aoi <- suppressWarnings(st_cast(aoi, to = "POLYGON"))[1, ]
   portfolio <- init_portfolio(aoi,
     years = 2000:2020,
     cores = 1,
     outdir = outdir,
     tmpdir = tmpdir,
-  )
-
-  portfolio <- init_portfolio(aoi,
-    years = 2000:2020,
-    cores = 1,
-    outdir = outdir,
-    tmpdir = tmpdir,
-    add_resources = FALSE
+    add_resources = FALSE,
+    verbose = FALSE
   )
 
   expect_message(
     get_resources(portfolio,
-      resources = c("treecover2000", "lossyear", "greenhouse")
+      resources = c("treecover2000", "lossyear", "greenhouse"),
+      vers_lossyear = "GFC-2020-v1.8"
     ),
     "Setting to default value of"
   )
@@ -42,32 +37,9 @@ test_that("get_resources works", {
     "requested resource is not supported"
   )
 
-  expect_message(
-    get_resources(portfolio,
-      resources = c("treecover2000", "lossyear", "greenhouse"),
-      vers_treecover = "GFC-2020-v1.8",
-      vers_lossyear = "GFC-2020-v1.8"
-    ),
-    "Starting process to download resource"
-  )
-
-  expect_warning(
-    get_resources(portfolio,
-      resources = c("lossyear"),
-      vers_lossyear = "not_available"
-    ),
-    "Download for resource lossyear failed. Returning unmodified portfolio object."
-  )
-
-  expect_message(
-    get_resources(portfolio,
-      resources = c("treecover2000", "lossyear", "greenhouse")
-    ),
-    "Skipping existing files in output directory"
-  )
-
   portfolio2 <- get_resources(portfolio,
-    resources = c("treecover2000", "lossyear", "greenhouse")
+    resources = c("treecover2000", "lossyear", "greenhouse"),
+    vers_lossyear = "GFC-2020-v1.8", vers_treecover = "GFC-2020-v1.8"
   )
 
   expect_message(
